==> open-xchange-core_6.22.0.orig.tar.bz2: open-xchange-core-6.22.0/com.openexchange.file.storage/src/com/openexchange/file/storage/GenericMethodSupport.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.file.storage;

import java.util.Date;

/**
 * {@link GenericMethodSupport}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 */
public class GenericMethodSupport {

    protected <T> T get(final int i, final Class<T> klass, final Object... args) {
        if (i >= args.length) {
            return null;
        }
        return (T) args[i];
    }

    protected File md(final int i, final Object... args) {
        return get(i, File.class, args);
    }

    protected File md(final Object... args) {
        return md(0, args);
    }

    protected String string(final int i, final Object... args) {
        if (args[i] == null || args.length <= i) {
            return null;
        }
        return args[i].toString();
    }

    protected int integer(final int i, final Object... args) {
        if (args[i] == null || args.length <= i) {
            return -1;
        }
        final Object o = args[i];
        if (o instanceof Number) {
            return ((Number) o).intValue();
        } else if (o instanceof String) {
            return Integer.parseInt((String) o);
        } else {
            return integer(0, o.toString());
        }
    }

    protected Date date(final int i, final Object... args) {
        if (args[i] == null || args.length <= i) {
            return null;
        }
        final Object o = args[i];

        if (o instanceof Date) {
            return (Date) o;
        }

        return new Date(coerceToLong(o));
    }

    protected long longValue(final int i, final Object... args) {
        if (args[i] == null || args.length <= i) {
            return -1;
        }
        return coerceToLong(args[i]);
    }

    private long coerceToLong(final Object o) {
        if (o instanceof Number) {
            return ((Number) o).longValue();
        } else if (o instanceof String) {
            return Long.parseLong((String) o);
        } else {
            return coerceToLong(o.toString());
        }
    }

}

==> open-xchange-core_7.4.2.orig.tar.bz2: open-xchange-core-7.4.2/com.openexchange.file.storage/src/com/openexchange/file/storage/GenericMethodSupport.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.file.storage;

import java.util.Date;

/**
 * {@link GenericMethodSupport}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 */
public class GenericMethodSupport {

    protected <T> T get(final int i, final Class<T> klass, final Object... args) {
        if (i >= args.length) {
            return null;
        }
        return (T) args[i];
    }

    protected File md(final int i, final Object... args) {
        return get(i, File.class, args);
    }

    protected File md(final Object... args) {
        return md(0, args);
    }

    protected String string(final int i, final Object... args) {
        if (args[i] == null || args.length <= i) {
            return null;
        }
        return args[i].toString();
    }

    protected int integer(final int i, final Object... args) {
        if (args[i] == null || args.length <= i) {
            return -1;
        }
        final Object o = args[i];
        if (o instanceof Number) {
            return ((Number) o).intValue();
        }
        return Integer.parseInt(o.toString());
    }

    protected Date date(final int i, final Object... args) {
        if (args[i] == null || args.length <= i) {
            return null;
        }
        final Object o = args[i];

        if (o instanceof Date) {
            return (Date) o;
        }

        return new Date(coerceToLong(o));
    }

    protected long longValue(final int i, final Object... args) {
        if (args[i] == null || args.length <= i) {
            return -1;
        }
        return coerceToLong(args[i]);
    }

    private long coerceToLong(final Object o) {
        if (o instanceof Number) {
            return ((Number) o).longValue();
        }
        return Long.parseLong(o.toString());
    }

}
